=========
Notebooks
=========

.. toctree::
   :maxdepth: 0

   Deploying SKLearn Model <sklearn>
   Deploying XGBoost Model <xgboost>
   Deploying Tensorflow Model <tensorflow>
   Deploying PyTorch Model <pytorch>
   Deploying Python Function Model <pyfunc>
   Custom Metrics <metrics>
   Batch Prediction <batch_iris>
   Predicting NY Taxi Fare Using Batch Prediction <batch_taxi>